@@ -101,5 +101,37 @@ utils::globalVariables(c(
   "amount_score_raw_quant",
   "amount_score_rasch",
   "total_score_raw",
-  "total_score_rasch"
+  "total_score_rasch",
+  "n_breaks",
+  "dur_cat",
+  "bout",
+  "duration",
+  "cum_frac_time",
+  "cum_frac_bout",
+  "nls",
+  "new_bout",
+  "new_intensity_category",
+  "valid_days",
+  "ig",
+  "M1/3",
+  "M120",
+  "M60",
+  "M30",
+  "M15",
+  "M5",
+  "metric",
+  "val",
+  "cutpoint",
+  "x_lab",
+  "y_lab",
+  ":=",
+  "value_maj",
+  "Metric",
+  "Indicateur",
+  "bin_start",
+  "bin_mid",
+  "bin_label",
+  "lm",
+  "days",
+  "."
   ))
